#ifndef __KP_NEW_SPLIT_WORKOUT_DIALOG_H
#define __KP_NEW_SPLIT_WORKOUT_DIALOG_H

#include <gtk/gtk.h>
#include "../kputil.h"
#include "../kptraininglog.h"

#define KP_TYPE_NEW_SPLIT_WORKOUT_DIALOG         (kp_new_split_workout_dialog_get_type ())
#define KP_NEW_SPLIT_WORKOUT_DIALOG(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), KP_TYPE_NEW_SPLIT_WORKOUT_DIALOG, KPNewSplitWorkoutDialog))
#define KP_NEW_SPLIT_WORKOUT_DIALOG_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), KP_TYPE_NEW_SPLIT_WORKOUT_DIALOG, KPNewSplitWorkoutDialogClass))
#define KP_IS_NEW_SPLIT_WORKOUT_DIALOG(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), KP_TYPE_NEW_SPLIT_WORKOUT_DIALOG))
#define KP_IS_NEW_SPLIT_WORKOUT_DIALOG_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), KP_TYPE_NEW_SPLIT_WORKOUT_DIALOG))
#define KP_NEW_SPLIT_WORKOUT_DIALOG_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), KP_TYPE_NEW_SPLIT_WORKOUT_DIALOG, KPNewSplitWorkoutDialogClass))

typedef struct
{
  GtkDialog       parent;

  gpointer        private_data;
} KPNewSplitWorkoutDialog;

typedef struct
{
  GtkDialogClass  parent_class;
} KPNewSplitWorkoutDialogClass;

GType           kp_new_split_workout_dialog_get_type    (void);

GtkWidget      *kp_new_split_workout_dialog_new         (KPDate *date,
                                                         KPCalendarEntry *entry);

#endif /* __KP_NEW_SPLIT_WORKOUT_DIALOG_H */
